==> apache-shardingsphere-5.5.1-src.zip: apache-shardingsphere-5.5.1-src-release/proxy/backend/core/src/main/java/org/apache/shardingsphere/proxy/backend/connector/sane/DialectSaneQueryResultEngine.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.proxy.backend.connector.sane;

import org.apache.shardingsphere.infra.executor.sql.execute.result.ExecuteResult;
import org.apache.shardingsphere.infra.database.core.spi.DatabaseTypedSPI;
import org.apache.shardingsphere.infra.spi.annotation.SingletonSPI;
import org.apache.shardingsphere.sql.parser.statement.core.statement.SQLStatement;

import java.sql.SQLException;
import java.util.Optional;

/**
 * Dialect sane query result engine.
 */
@SingletonSPI
public interface DialectSaneQueryResultEngine extends DatabaseTypedSPI {
    
    /**
     * Get sane query result.
     *
     * @param sqlStatement SQL statement
     * @param ex SQL exception
     * @return sane execute result
     */
    Optional<ExecuteResult> getSaneQueryResult(SQLStatement sqlStatement, SQLException ex);
}

==> apache-shardingsphere-5.5.3-src.zip: apache-shardingsphere-5.5.3-src-release/proxy/backend/core/src/main/java/org/apache/shardingsphere/proxy/backend/connector/sane/DialectSaneQueryResultEngine.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.proxy.backend.connector.sane;

import org.apache.shardingsphere.database.connector.core.spi.DatabaseTypedSPI;
import org.apache.shardingsphere.infra.executor.sql.execute.result.ExecuteResult;
import org.apache.shardingsphere.infra.spi.annotation.SingletonSPI;
import org.apache.shardingsphere.sql.parser.statement.core.statement.SQLStatement;

import java.sql.SQLException;
import java.util.Optional;

/**
 * Dialect sane query result engine.
 */
@SingletonSPI
public interface DialectSaneQueryResultEngine extends DatabaseTypedSPI {
    
    /**
     * Get sane query result.
     *
     * @param sqlStatement SQL statement
     * @param ex SQL exception
     * @return sane execute result
     */
    Optional<ExecuteResult> getSaneQueryResult(SQLStatement sqlStatement, SQLException ex);
}
